library unify.tool;

import 'dart:io';
import 'dart:convert';

import 'unify.dart';
export 'unify.dart';

const List<String> _emailEnvVars = const <String>[
  "UNIFY_EMAIL",
  "UNIFY_USERNAME",
  "UNIFY_USER"
];

const List<String> _passwordEnvVars = const <String>[
  "UNIFY_PASSWORD",
  "UNIFY_PASS",
  "UNIFY_PWD"
];

String _getEnvKey(List<String> possible) {
  for (var key in possible) {
    var dartEnvValue = new String.fromEnvironment(key);
    if (dartEnvValue != null) {
      return dartEnvValue;
    }

    if (Platform.environment.containsKey(key) &&
        Platform.environment[key].isNotEmpty) {
      return Platform.environment[key];
    }
  }

  throw new Exception(
      "Expected environment variable '${possible.first}' to be present.");
}

UnifyClient getUnifyClient(
    {String unifyUsername,
    String unifyPassword,
    UnifyApiEndpoints endpoints,
    String domain = "mobile.myunifycrm.com"}) {
  var email = unifyUsername ?? _getEnvKey(_emailEnvVars).trim();
  var password = unifyPassword ?? _getEnvKey(_passwordEnvVars);

  if (password.startsWith("base64:")) {
    password =
        const Utf8Decoder().convert(const Base64Decoder().convert(password, 7));
  }

  if (password.endsWith("\n")) {
    password = password.substring(0, password.length - 1);
  }

  return new UnifyClient(email, password, endpoints: endpoints, domain: domain);
}
